@@ -26,7 +26,7 @@ def install(basepath, name):
     start_file_path = os.path.join(basepath,"start.sh")
     start_file = open(start_file_path, "a")
     start_file.write("#!/bin/bash\n")
-    start_file.write("gunicorn server:app")
+    start_file.write("gunicorn server:app\n")
     start_file.close()
 
     old_perms = os.stat(start_file_path)
@@ -45,7 +45,8 @@ def install_examples(basepath, name):
 
     if os.path.exists(os.path.join(basepath,"Procfile")):
         proc_file = open(os.path.join(basepath,"Procfile"), "a")
-        proc_file.write("##Other commands examples:\n")
+        proc_file.write("# Gunicorn commands examples:\n")
+        proc_file.write("# web: gunicorn server:app # gunicorn server \n")
         proc_file.write("# web: gunicorn server:app -k gevent # non blocking server\n")
         proc_file.close()
 
